import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class NumberField extends StatelessWidget {
  final int? initialValue;
  final FormFieldValidator<int>? validator;
  final TextInputAction? textInputAction;
  final Function()? onEditingComplete;
  final TextEditingController? controller;
  final FocusNode? focusNode;
  final bool autofocus;
  final bool enabled;
  final String labelText;
  final void Function(int?) onChanged;

  const NumberField({
    super.key,
    this.initialValue,
    this.validator,
    this.textInputAction,
    this.onEditingComplete,
    this.controller,
    this.focusNode,
    this.autofocus = false,
    this.enabled = true,
    required this.labelText,
    required this.onChanged,
  });

  @override
  Widget build(BuildContext context) {
    var validator = this.validator;
    return TextFormField(
      initialValue: initialValue?.toString() ?? '',
      validator:
          validator == null ? null : (v) => validator(int.tryParse(v ?? '')),
      keyboardType: TextInputType.number,
      inputFormatters: [
        FilteringTextInputFormatter.digitsOnly,
      ],
      focusNode: focusNode,
      controller: controller,
      autofocus: autofocus,
      enabled: enabled,
      onChanged: (v) => onChanged(int.tryParse(v)),
      decoration: InputDecoration(
        enabled: enabled,
        labelText: labelText,
      ),
      onEditingComplete: onEditingComplete,
      textInputAction: textInputAction,
    );
  }
}
